==> activereports-angular-5.0.0.tgz: package/README.md <==
# ActiveReportsJS Angular



[A Complete Angular Reporting Tool](https://www.grapecity.com/activereportsjs/angular-reporting-tool) for Enterprise Applications.

ActiveReportsJS is a powerful reporting tool for Angular applications that allows developers and report authors to easily design and display reports within their applications. With a wide range of features, such as [drill-down](https://www.grapecity.com/activereportsjs/demos/Reports/DrillDown2/purejs), [runtime data filtering](https://www.grapecity.com/activereportsjs/demos/Reports/RuntimeFilters/purejs), and [parameter-driven reports](https://www.grapecity.com/activereportsjs/demos/Reports/ParameterDriven/purejs),ActiveReportsJS simplifies the process of creating and managing reports, enabling developers to enhance their applications' capabilities and deliver valuable insights to end-users.

<p align="center">
  <img src="https://cdn.mescius.io/umb/media/spml4vl4/npm-activereportsjs.png" width="300" alt="dashboard image" />
</p>

The ActiveReportsJS suite includes both a [Report Viewer](https://www.grapecity.com/activereportsjs/docs/v4.0/GettingStarted/QuickStart) and [Report Designer](https://www.grapecity.com/activereportsjs/docs/v4.0/GettingStarted/QuickStart-ARJS-Designer-Component) component. The Viewer allows end-users to view and interact with reports, while the Designer enables developers to design and customize reports, either within the same web application or by using the Standalone Report Designer.


## Installation

To install the latest release version:

`npm install @grapecity/activereports-angular`

To install a specific version:

`npm install @grapecity/activereports-angular@{VersionNumber}`

## Documentation

For more information on how to use ActiveReportsJS, online documentation can be found here:
* [Documentation](https://www.grapecity.com/activereportsjs/docs/GettingStarted/Introduction) 
* [API Reference](https://www.grapecity.com/activereportsjs/api/modules/Core)

## Samples

To quickly jump in with ActiveReportsJS, check out our [Demo Gallery](https://www.grapecity.com/activereportsjs/demos/).

## Licensing

Read more about [ActiveReportsJS Licensing](https://www.grapecity.com/activereportsjs/pricing).

## Keywords
* [angular](https://www.npmjs.com/search?q=keywords:angular)
* [activereports](https://www.npmjs.com/search?q=keywords:activereports)
* [grapecity](https://www.npmjs.com/search?q=keywords:grapecity)
* [arjs](https://www.npmjs.com/search?q=keywords:arjs)
* [reporting](https://www.npmjs.com/search?q=keywords:reporting)
* [pagereport](https://www.npmjs.com/search?q=keywords:pagereport)
* [pagedocument](https://www.npmjs.com/search?q=keywords:pagedocument)
* [viewer](https://www.npmjs.com/search?q=keywords:viewer)
* [rdlx](https://www.npmjs.com/search?q=keywords:rdlx)
* [rdl](https://www.npmjs.com/search?q=keywords:rdl)

==> activereports-angular-5.1.4.tgz: package/README.md <==
# ActiveReportsJS Angular



[A Complete Angular Reporting Tool](https://www.grapecity.com/activereportsjs/angular-reporting-tool) for Enterprise Applications.

ActiveReportsJS is a powerful reporting tool for Angular applications that allows developers and report authors to easily design and display reports within their applications. With a wide range of features, such as [drill-down](https://www.grapecity.com/activereportsjs/demos/Reports/DrillDown2/purejs), [runtime data filtering](https://www.grapecity.com/activereportsjs/demos/Reports/RuntimeFilters/purejs), and [parameter-driven reports](https://www.grapecity.com/activereportsjs/demos/Reports/ParameterDriven/purejs),ActiveReportsJS simplifies the process of creating and managing reports, enabling developers to enhance their applications' capabilities and deliver valuable insights to end-users.

<p align="center">
  <img src="https://cdn.mescius.io/umb/media/spml4vl4/npm-activereportsjs.png" width="300" alt="dashboard image" />
</p>

The ActiveReportsJS suite includes both a [Report Viewer](https://www.grapecity.com/activereportsjs/docs/GettingStarted/QuickStart) and [Report Designer](https://www.grapecity.com/activereportsjs/docs/GettingStarted/QuickStart-ARJS-Designer-Component) component. The Viewer allows end-users to view and interact with reports, while the Designer enables developers to design and customize reports, either within the same web application or by using the Standalone Report Designer.


## Installation

To install the latest release version:

`npm install @grapecity/activereports-angular`

To install a specific version:

`npm install @grapecity/activereports-angular@{VersionNumber}`

## Documentation

For more information on how to use ActiveReportsJS, online documentation can be found here:
* [Documentation](https://www.grapecity.com/activereportsjs/docs/GettingStarted/Introduction) 
* [API Reference](https://www.grapecity.com/activereportsjs/api/modules/Core)

## Samples

To quickly jump in with ActiveReportsJS, check out our [Demo Gallery](https://www.grapecity.com/activereportsjs/demos/).

## Licensing

Read more about [ActiveReportsJS Licensing](https://www.grapecity.com/activereportsjs/pricing).

## Keywords
* [angular](https://www.npmjs.com/search?q=keywords:angular)
* [activereports](https://www.npmjs.com/search?q=keywords:activereports)
* [grapecity](https://www.npmjs.com/search?q=keywords:grapecity)
* [arjs](https://www.npmjs.com/search?q=keywords:arjs)
* [reporting](https://www.npmjs.com/search?q=keywords:reporting)
* [pagereport](https://www.npmjs.com/search?q=keywords:pagereport)
* [pagedocument](https://www.npmjs.com/search?q=keywords:pagedocument)
* [viewer](https://www.npmjs.com/search?q=keywords:viewer)
* [rdlx](https://www.npmjs.com/search?q=keywords:rdlx)
* [rdl](https://www.npmjs.com/search?q=keywords:rdl)
